@@ -370,7 +370,7 @@ example_callable_media_manager_type_foreach_channel_class (GType type,
 
   func (type, table, allowed_properties, user_data);
 
-  g_hash_table_destroy (table);
+  g_hash_table_unref (table);
 }
 
 static gboolean
