@@ -161,7 +161,7 @@ example_echo_2_im_manager_close_all (ExampleEcho2ImManager *self)
       GHashTable *tmp = self->priv->channels;
 
       self->priv->channels = NULL;
-      g_hash_table_destroy (tmp);
+      g_hash_table_unref (tmp);
     }
 
   if (self->priv->status_changed_id != 0)
@@ -268,8 +268,8 @@ static const gchar * const allowed_properties[] = {
 };
 
 static void
-example_echo_2_im_manager_foreach_channel_class (TpChannelManager *manager,
-    TpChannelManagerChannelClassFunc func,
+example_echo_2_im_manager_type_foreach_channel_class (GType type,
+    TpChannelManagerTypeChannelClassFunc func,
     gpointer user_data)
 {
   GHashTable *table = tp_asv_new (
@@ -278,9 +278,9 @@ example_echo_2_im_manager_foreach_channel_class (TpChannelManager *manager,
       TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, G_TYPE_UINT, TP_HANDLE_TYPE_CONTACT,
       NULL);
 
-  func (manager, table, allowed_properties, user_data);
+  func (type, table, allowed_properties, user_data);
 
-  g_hash_table_destroy (table);
+  g_hash_table_unref (table);
 }
 
 static gboolean
@@ -369,7 +369,7 @@ channel_manager_iface_init (gpointer g_iface,
   TpChannelManagerIface *iface = g_iface;
 
   iface->foreach_channel = example_echo_2_im_manager_foreach_channel;
-  iface->foreach_channel_class = example_echo_2_im_manager_foreach_channel_class;
+  iface->type_foreach_channel_class = example_echo_2_im_manager_type_foreach_channel_class;
   iface->create_channel = example_echo_2_im_manager_create_channel;
   iface->ensure_channel = example_echo_2_im_manager_ensure_channel;
   /* In this channel manager, Request has the same semantics as Ensure */
