@@ -23,6 +23,7 @@
 #define TP_CHANNEL_DISPATCH_OPERATION_H
 
 #include <telepathy-glib/account.h>
+#include <telepathy-glib/base-client.h>
 #include <telepathy-glib/connection.h>
 #include <telepathy-glib/dbus.h>
 #include <telepathy-glib/defs.h>
@@ -30,8 +31,8 @@
 
 G_BEGIN_DECLS
 
-typedef struct _TpChannelDispatchOperation
-    TpChannelDispatchOperation;
+
+/* TpChannelDispatchOperation is defined in base-client.h */
 typedef struct _TpChannelDispatchOperationClass
     TpChannelDispatchOperationClass;
 typedef struct _TpChannelDispatchOperationPrivate
@@ -121,7 +122,7 @@ gboolean tp_channel_dispatch_operation_claim_finish (
 void tp_channel_dispatch_operation_handle_with_time_async (
     TpChannelDispatchOperation *self,
     const gchar *handler,
-    gint64 user_action_timestamp,
+    gint64 user_action_time,
     GAsyncReadyCallback callback,
     gpointer user_data);
 
@@ -130,6 +131,51 @@ gboolean tp_channel_dispatch_operation_handle_with_time_finish (
     GAsyncResult *result,
     GError **error);
 
+void tp_channel_dispatch_operation_claim_with_async (
+    TpChannelDispatchOperation *self,
+    TpBaseClient *client,
+    GAsyncReadyCallback callback,
+    gpointer user_data);
+
+gboolean tp_channel_dispatch_operation_claim_with_finish (
+    TpChannelDispatchOperation *self,
+    GAsyncResult *result,
+    GError **error);
+
+/* Reject API */
+
+void tp_channel_dispatch_operation_close_channels_async (
+    TpChannelDispatchOperation *self,
+    GAsyncReadyCallback callback,
+    gpointer user_data);
+
+gboolean tp_channel_dispatch_operation_close_channels_finish (
+    TpChannelDispatchOperation *self,
+    GAsyncResult *result,
+    GError **error);
+
+void tp_channel_dispatch_operation_leave_channels_async (
+    TpChannelDispatchOperation *self,
+    TpChannelGroupChangeReason reason,
+    const gchar *message,
+    GAsyncReadyCallback callback,
+    gpointer user_data);
+
+gboolean tp_channel_dispatch_operation_leave_channels_finish (
+    TpChannelDispatchOperation *self,
+    GAsyncResult *result,
+    GError **error);
+
+void tp_channel_dispatch_operation_destroy_channels_async (
+    TpChannelDispatchOperation *self,
+    GAsyncReadyCallback callback,
+    gpointer user_data);
+
+gboolean tp_channel_dispatch_operation_destroy_channels_finish (
+    TpChannelDispatchOperation *self,
+    GAsyncResult *result,
+    GError **error);
+
 G_END_DECLS
 
 #include <telepathy-glib/_gen/tp-cli-channel-dispatch-operation.h>
