@@ -278,6 +278,12 @@ GQuark tp_connection_get_feature_quark_avatar_requirements (void) G_GNUC_CONST;
 TpAvatarRequirements * tp_connection_get_avatar_requirements (
     TpConnection *self);
 
+#define TP_CONNECTION_FEATURE_ALIASING \
+  (tp_connection_get_feature_quark_aliasing ())
+GQuark tp_connection_get_feature_quark_aliasing (void) G_GNUC_CONST;
+
+gboolean tp_connection_can_set_contact_alias (TpConnection *self);
+
 #define TP_CONNECTION_FEATURE_BALANCE \
   (tp_connection_get_feature_quark_balance ())
 GQuark tp_connection_get_feature_quark_balance (void) G_GNUC_CONST;
