@@ -684,21 +684,7 @@ _tp_handle_channels_context_prepare_finish (
     GAsyncResult *result,
     GError **error)
 {
-  GSimpleAsyncResult *simple;
-
-  g_return_val_if_fail (TP_IS_HANDLE_CHANNELS_CONTEXT (self), FALSE);
-  g_return_val_if_fail (G_IS_SIMPLE_ASYNC_RESULT (result), FALSE);
-
-  simple = G_SIMPLE_ASYNC_RESULT (result);
-
-  if (g_simple_async_result_propagate_error (simple, error))
-    return FALSE;
-
-  g_return_val_if_fail (g_simple_async_result_is_valid (result,
-          G_OBJECT (self), _tp_handle_channels_context_prepare_async),
-      FALSE);
-
-  return TRUE;
+  _tp_implement_finish_void (self, _tp_handle_channels_context_prepare_async);
 }
 
 /**
