@@ -46,6 +46,9 @@ GList * _tp_create_channel_request_list (TpSimpleClientFactory *factory,
 
 /* Copied from wocky/wocky-utils.h */
 
+gboolean _tp_enum_from_nick (GType enum_type, const gchar *nick, gint *value);
+const gchar *_tp_enum_to_nick (GType enum_type, gint value);
+
 #define _tp_implement_finish_void(source, tag) \
     if (g_simple_async_result_propagate_error (\
       G_SIMPLE_ASYNC_RESULT (result), error)) \
