@@ -383,7 +383,7 @@ call_add_dispatch (Test *test)
   g_main_loop_run (test->mainloop);
 
   g_ptr_array_foreach (channels, free_channel_details, NULL);
-  g_ptr_array_free (channels, TRUE);
+  g_ptr_array_unref (channels);
   g_hash_table_unref (properties);
 }
 
