@@ -30,6 +30,8 @@ G_DEFINE_TYPE_WITH_CODE (TpTestsFileTransferChannel,
     TP_TYPE_BASE_CHANNEL,
     G_IMPLEMENT_INTERFACE (TP_TYPE_SVC_CHANNEL_TYPE_FILE_TRANSFER,
       file_transfer_iface_init);
+    G_IMPLEMENT_INTERFACE (TP_TYPE_SVC_CHANNEL_INTERFACE_FILE_TRANSFER_METADATA,
+      NULL);
     )
 
 static const char *
@@ -49,6 +51,8 @@ enum /* properties */
   PROP_STATE,
   PROP_TRANSFERRED_BYTES,
   PROP_URI,
+  PROP_SERVICE_NAME,
+  PROP_METADATA,
   N_PROPS,
 };
 
@@ -62,6 +66,8 @@ struct _TpTestsFileTransferChannelPrivate {
     TpFileTransferState state;
     guint64 transferred_bytes;
     gchar *uri;
+    gchar *service_name;
+    GHashTable *metadata;
 
     /* Hidden properties */
     TpFileHashType content_hash_type;
@@ -138,10 +144,12 @@ dispose (GObject *object)
   g_free (self->priv->description);
   g_free (self->priv->filename);
   g_free (self->priv->uri);
+  g_free (self->priv->service_name);
 
   tp_clear_pointer (&self->priv->address, tp_g_value_slice_free);
   tp_clear_pointer (&self->priv->available_socket_types, g_hash_table_unref);
   tp_clear_pointer (&self->priv->access_control_param, tp_g_value_slice_free);
+  tp_clear_pointer (&self->priv->metadata, g_hash_table_unref);
 
   if (self->priv->unix_address != NULL)
     g_unlink (self->priv->unix_address);
@@ -209,6 +217,14 @@ get_property (GObject *object,
         g_value_set_string (value, self->priv->uri);
         break;
 
+      case PROP_SERVICE_NAME:
+        g_value_set_string (value, self->priv->service_name);
+        break;
+
+      case PROP_METADATA:
+        g_value_set_boxed (value, self->priv->metadata);
+        break;
+
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
         break;
@@ -272,6 +288,14 @@ set_property (GObject *object,
         self->priv->uri = g_value_dup_string (value);
         break;
 
+      case PROP_SERVICE_NAME:
+        self->priv->service_name = g_value_dup_string (value);
+        break;
+
+      case PROP_METADATA:
+        self->priv->metadata = g_value_dup_boxed (value);
+        break;
+
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
         break;
@@ -302,6 +326,8 @@ fill_immutable_properties (TpBaseChannel *self,
       TP_IFACE_CHANNEL_TYPE_FILE_TRANSFER, "Size",
       TP_IFACE_CHANNEL_TYPE_FILE_TRANSFER, "Description",
       TP_IFACE_CHANNEL_TYPE_FILE_TRANSFER, "Date",
+      TP_IFACE_CHANNEL_INTERFACE_FILE_TRANSFER_METADATA, "ServiceName",
+      TP_IFACE_CHANNEL_INTERFACE_FILE_TRANSFER_METADATA, "Metadata",
       NULL);
 
   /* URI is immutable only for outgoing transfers */
@@ -313,6 +339,237 @@ fill_immutable_properties (TpBaseChannel *self,
     }
 }
 
+static void
+change_state (TpTestsFileTransferChannel *self,
+    TpFileTransferState state,
+    TpFileTransferStateChangeReason reason)
+{
+  self->priv->state = state;
+
+  tp_svc_channel_type_file_transfer_emit_file_transfer_state_changed (self,
+      state, reason);
+}
+
+/* This function imitates the beginning of a filetransfer. It sets the state
+ * to open, and connects to the "incoming" signal of the GSocketService.
+ */
+static gboolean
+start_file_transfer (gpointer data)
+{
+  TpTestsFileTransferChannel *self = (TpTestsFileTransferChannel *) data;
+
+  DEBUG ("Setting TP_FILE_TRANSFER_STATE_OPEN");
+  change_state (self, TP_FILE_TRANSFER_STATE_OPEN,
+      TP_FILE_TRANSFER_STATE_CHANGE_REASON_REQUESTED);
+
+  g_object_notify ((GObject *) data, "state");
+  DEBUG ("Fired state signal");
+
+//  g_signal_connect (self->priv->service, "incoming", G_CALLBACK
+//      (incoming_file_transfer_cb));
+
+  return FALSE;
+}
+
+static gboolean
+check_address_type (TpTestsFileTransferChannel *self,
+    TpSocketAddressType address_type,
+    TpSocketAccessControl access_control)
+{
+  GArray *arr;
+  guint i;
+
+  arr = g_hash_table_lookup (self->priv->available_socket_types,
+      GUINT_TO_POINTER (address_type));
+  if (arr == NULL)
+    return FALSE;
+
+  for (i = 0; i < arr->len; i++)
+    {
+      if (g_array_index (arr, TpSocketAccessControl, i) == access_control)
+        return TRUE;
+    }
+
+  return FALSE;
+}
+
+static void
+service_incoming_cb (GSocketService *service,
+    GSocketConnection *connection,
+    GObject *source_object,
+    gpointer user_data)
+{
+  TpTestsFileTransferChannel *self = user_data;
+  GError *error = NULL;
+
+  DEBUG ("Servicing incoming connection");
+  if (self->priv->access_control == TP_SOCKET_ACCESS_CONTROL_CREDENTIALS)
+    {
+      GCredentials *creds;
+      guchar byte;
+
+      /* TODO: Async version */
+      creds = tp_unix_connection_receive_credentials_with_byte (
+          connection, &byte, NULL, &error);
+      g_assert_no_error (error);
+
+      g_assert_cmpuint (byte, ==,
+          g_value_get_uchar (self->priv->access_control_param));
+      g_object_unref (creds);
+    }
+  else if (self->priv->access_control == TP_SOCKET_ACCESS_CONTROL_PORT)
+    {
+      GSocketAddress *addr;
+      guint16 port;
+
+      addr = g_socket_connection_get_remote_address (connection, &error);
+      g_assert_no_error (error);
+
+      port = g_inet_socket_address_get_port (G_INET_SOCKET_ADDRESS (addr));
+
+      g_assert_cmpuint (port, ==,
+          g_value_get_uint (self->priv->access_control_param));
+
+      g_object_unref (addr);
+    }
+}
+
+static void
+file_transfer_provide_file (TpSvcChannelTypeFileTransfer *iface,
+    TpSocketAddressType address_type,
+    TpSocketAccessControl access_control,
+    const GValue *access_control_param,
+    DBusGMethodInvocation *context)
+{
+  TpTestsFileTransferChannel *self = (TpTestsFileTransferChannel *) iface;
+  TpBaseChannel *base_chan = (TpBaseChannel *) iface;
+  GError *error = NULL;
+
+  if (tp_base_channel_is_requested (base_chan) != TRUE)
+    {
+      g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+          "File transfer is not outgoing. Cannot offer file");
+      goto fail;
+    }
+
+  if (self->priv->state != TP_FILE_TRANSFER_STATE_PENDING &&
+      self->priv->state != TP_FILE_TRANSFER_STATE_ACCEPTED)
+    {
+      g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+          "File transfer is not pending or accepted. Cannot offer file");
+      goto fail;
+    }
+
+  if (self->priv->address != NULL)
+    {
+      g_set_error (&error, TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
+          "ProvideFile has already been called for this channel");
+      goto fail;
+    }
+
+  if (!check_address_type (self, address_type, access_control))
+    {
+      g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+          "Address type %i is not supported with access control %i",
+          address_type, access_control);
+      goto fail;
+    }
+
+  self->priv->address = _tp_create_local_socket (address_type, access_control,
+      &self->priv->service, &self->priv->unix_address, &error);
+
+  if (self->priv->address == NULL)
+      {
+        g_set_error (&error, TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
+            "Could not set up local socket");
+        goto fail;
+      }
+
+  self->priv->address_type = address_type;
+  self->priv->access_control = access_control;
+
+  DEBUG ("Waiting 500ms and setting state to OPEN");
+  g_timeout_add (500, start_file_transfer, self);
+
+  // connect to self->priv->service incoming signal
+  // when the signal returns, add x bytes per n seconds using timeout
+  // then close the socket
+  // g_output_stream_write_async
+
+  tp_svc_channel_type_file_transfer_return_from_provide_file (context,
+      self->priv->address);
+
+  return;
+
+fail:
+  dbus_g_method_return_error (context, error);
+  g_error_free (error);
+}
+
+static void
+file_transfer_accept_file (TpSvcChannelTypeFileTransfer *iface,
+    TpSocketAddressType address_type,
+    TpSocketAccessControl access_control,
+    const GValue *access_control_param,
+    guint64 offset,
+    DBusGMethodInvocation *context)
+{
+  TpTestsFileTransferChannel *self = (TpTestsFileTransferChannel *) iface;
+  TpBaseChannel *base_chan = (TpBaseChannel *) iface;
+  GError *error = NULL;
+  GValue *address;
+
+  if (tp_base_channel_is_requested (base_chan) == TRUE)
+    {
+      g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+          "File transfer is not incoming. Cannot accept file");
+      goto fail;
+    }
+
+  if (self->priv->state != TP_FILE_TRANSFER_STATE_PENDING)
+    {
+      g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+          "File transfer is not in the pending state");
+      goto fail;
+    }
+
+  if (!check_address_type (self, address_type, access_control))
+    {
+      g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+          "Address type %i is not supported with access control %i",
+          address_type, access_control);
+      goto fail;
+    }
+
+  address = _tp_create_local_socket (address_type, access_control,
+      &self->priv->service, &self->priv->unix_address, &error);
+
+  tp_g_signal_connect_object (self->priv->service, "incoming",
+      G_CALLBACK (service_incoming_cb), self, 0);
+
+  self->priv->access_control = access_control;
+  self->priv->access_control_param = tp_g_value_slice_dup (
+      access_control_param);
+
+  DEBUG ("Setting TP_FILE_TRANSFER_STATE_ACCEPTED");
+  change_state (self, TP_FILE_TRANSFER_STATE_ACCEPTED,
+      TP_FILE_TRANSFER_STATE_CHANGE_REASON_REQUESTED);
+
+  DEBUG ("Waiting 500ms and setting state to OPEN");
+  g_timeout_add (500, start_file_transfer, self);
+
+  tp_svc_channel_type_file_transfer_return_from_accept_file (context,
+      address);
+
+  tp_clear_pointer (&address, tp_g_value_slice_free);
+
+  return;
+
+fail:
+  dbus_g_method_return_error (context, error);
+  g_error_free (error);
+}
+
 static void
 tp_tests_file_transfer_channel_class_init (
     TpTestsFileTransferChannelClass *klass)
@@ -334,6 +591,12 @@ tp_tests_file_transfer_channel_class_init (
       { NULL }
   };
 
+  static TpDBusPropertiesMixinPropImpl metadata_props[] = {
+      { "ServiceName", "service-name", NULL },
+      { "Metadata", "metadata", NULL },
+      { NULL }
+  };
+
   object_class->constructor = constructor;
   object_class->get_property = get_property;
   object_class->set_property = set_property;
@@ -429,11 +692,32 @@ tp_tests_file_transfer_channel_class_init (
   g_object_class_install_property (object_class, PROP_URI,
       param_spec);
 
+  param_spec = g_param_spec_string ("service-name",
+      "ServiceName",
+      "The Metadata.ServiceName property of this channel",
+      "",
+      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
+  g_object_class_install_property (object_class, PROP_SERVICE_NAME,
+      param_spec);
+
+  param_spec = g_param_spec_boxed ("metadata",
+      "Metadata",
+      "The Metadata.Metadata property of this channel",
+      TP_HASH_TYPE_METADATA,
+      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
+  g_object_class_install_property (object_class, PROP_METADATA,
+      param_spec);
+
   tp_dbus_properties_mixin_implement_interface (object_class,
       TP_IFACE_QUARK_CHANNEL_TYPE_FILE_TRANSFER,
       tp_dbus_properties_mixin_getter_gobject_properties, NULL,
       file_transfer_props);
 
+  tp_dbus_properties_mixin_implement_interface (object_class,
+      TP_IFACE_QUARK_CHANNEL_INTERFACE_FILE_TRANSFER_METADATA,
+      tp_dbus_properties_mixin_getter_gobject_properties, NULL,
+      metadata_props);
+
   g_type_class_add_private (object_class,
       sizeof (TpTestsFileTransferChannelPrivate));
 }
@@ -441,13 +725,13 @@ tp_tests_file_transfer_channel_class_init (
 static void
 file_transfer_iface_init (gpointer iface, gpointer data)
 {
-#if 0
   TpSvcChannelTypeFileTransferClass *klass = iface;
 
 #define IMPLEMENT(x) tp_svc_channel_type_file_transfer_implement_##x (klass, \
     file_transfer_##x)
+  IMPLEMENT(accept_file);
+  IMPLEMENT(provide_file);
 #undef IMPLEMENT
-#endif
 }
 
 /* Return the address of the file transfer's socket */
